@@ -1,9 +1,13 @@
 from pydantic import BaseModel, Field
 from typing import Annotated
+from .heartbeat.config import HeartbeatConfigMixin
 from .resource.config import ResourceConfigMixin
 
 
-class InfraConfig(ResourceConfigMixin):
+class InfraConfig(
+    ResourceConfigMixin,
+    HeartbeatConfigMixin,
+):
     pass
 
 
