@@ -1,15 +1,15 @@
 import asyncio
 import os
 import psutil
-import traceback
 from collections import deque
 from datetime import datetime, timezone, timedelta
-from typing import Optional
+from google.cloud.pubsub_v1.publisher.futures import Future
 from uuid import UUID, uuid4
 from maleo.logging.enums import Level
 from maleo.logging.logger import EnvironmentT, ServiceKeyT, Application
-from maleo.schemas.application import ApplicationContext, OptionalApplicationContext
-from maleo.schemas.connection import OptionalConnectionContext
+from maleo.schemas.application import ApplicationContext, OptApplicationContext
+from maleo.schemas.google import PublisherHandler, ListOfPublisherHandlers
+from maleo.schemas.connection import OptConnectionContext
 from maleo.schemas.operation.action.system import SystemOperationAction
 from maleo.schemas.operation.context import generate
 from maleo.schemas.operation.enums import (
@@ -25,39 +25,56 @@ from maleo.schemas.response import (
     SingleDataResponse,
     MultipleDataResponse,
 )
-from maleo.schemas.security.authentication import OptionalAnyAuthentication
-from maleo.schemas.security.authorization import OptionalAnyAuthorization
-from maleo.schemas.security.impersonation import OptionalImpersonation
-from maleo.types.uuid import OptionalUUID
+from maleo.schemas.security.authentication import OptAnyAuthentication
+from maleo.schemas.security.authorization import OptAnyAuthorization
+from maleo.schemas.security.impersonation import OptImpersonation
+from maleo.types.uuid import OptUUID
+from maleo.utils.exception import extract_details
 from .config import ResourceConfig
 from .constants import STATUS_LOG_LEVEL
-from .schemas import CPUUsage, MemoryUsage, Usage, AggregateUsage, Measurement
-from .utils import aggregate_status
+from .schemas import (
+    CPUUsage,
+    MemoryUsage,
+    Usage,
+    RegularMeasurement,
+    AverageMeasurement,
+    PeakMeasurement,
+)
 
 
 class ResourceMonitor:
     def __init__(
         self,
+        operation_id: UUID,
+        started_at: datetime,
         config: ResourceConfig,
         logger: Application[EnvironmentT, ServiceKeyT],
-        application_context: OptionalApplicationContext = None,
+        publish: bool = False,
+        publisher: PublisherHandler | None = None,
+        operation_publishers: ListOfPublisherHandlers = [],
+        application_context: OptApplicationContext = None,
     ):
         self.application_context = (
             application_context
             if application_context is not None
             else ApplicationContext.from_env()
         )
+        self.operation_id = operation_id
+        self.started_at = started_at
         self.config = config
         self.logger = logger
+        self.publish = publish
+        self.publisher = publisher
+        self.operation_publishers = operation_publishers
         self.process = psutil.Process(os.getpid())
         self.cpu_window = deque(maxlen=self.config.measurement.window)
 
         # Store historical data with timestamps
-        self.measurement_history: deque[Measurement[Usage]] = deque(
-            maxlen=10_000
-        )  # Adjust max length as needed
+        self.measurement_history: deque[RegularMeasurement] = deque[
+            RegularMeasurement
+        ]()
         self.is_monitoring = False
-        self.monitor_task: Optional[asyncio.Task] = None
+        self.monitor_task: asyncio.Task | None = None
 
         # Operation context setup
         self.operation_context = generate(
@@ -67,17 +84,13 @@ class ResourceMonitor:
             type=SystemOperationType.METRIC_REPORT, details={"type": "resource"}
         )
 
-    async def start_monitoring(
-        self,
-        operation_id: OptionalUUID = None,
-    ) -> None:
+    async def start_monitoring(self) -> None:
         """Start the resource monitoring loop."""
-        operation_id = operation_id if operation_id is not None else uuid4()
         if self.is_monitoring:
             return
 
         self.is_monitoring = True
-        self.monitor_task = asyncio.create_task(self._monitor_loop(operation_id))
+        self.monitor_task = asyncio.create_task(self._monitor_loop())
 
     async def stop_monitoring(self) -> None:
         """Stop the resource monitoring loop."""
@@ -90,27 +103,39 @@ class ResourceMonitor:
                 pass
             self.monitor_task = None
 
-    async def _monitor_loop(
-        self,
-        operation_id: UUID,
-    ) -> None:
+    async def _monitor_loop(self) -> None:
         """Internal monitoring loop."""
-        count: int = 1
+        frequency = self.config.measurement.frequency
+        log_count: int = 1
+        publish_count: int = 1
         while self.is_monitoring:
             try:
                 await self._measure(
-                    operation_id, self.config.measurement.frequency == count
+                    frequency.should_log and frequency.log == log_count,
+                    frequency.should_publish and frequency.publish == publish_count,
                 )
-                if count >= self.config.measurement.frequency:
-                    count = 1
+
+                # Calculate log_count
+                if frequency.should_log and log_count >= frequency.log:
+                    log_count = 1
                 else:
-                    count += 1
+                    log_count += 1
+
+                # Calculate publish_count
+                if frequency.should_publish and publish_count >= frequency.publish:
+                    publish_count = 1
+                else:
+                    publish_count += 1
+
                 await asyncio.sleep(self.config.measurement.interval)
             except asyncio.CancelledError:
                 break
-            except Exception:
-                print("Error in resource monitoring:")
-                print(traceback.format_exc())
+            except Exception as e:
+                self.logger.error(
+                    "Unexpected error occured in resource monitoring",
+                    exc_info=True,
+                    extra={"json_fields": {"exc_details": extract_details(e)}},
+                )
                 await asyncio.sleep(self.config.measurement.interval)
 
     def _cleanup_old_entries(self) -> None:
@@ -119,7 +144,7 @@ class ResourceMonitor:
             return
 
         cutoff_time = datetime.now(tz=timezone.utc) - timedelta(
-            seconds=self.config.retention
+            seconds=self.config.measurement.retention
         )
 
         # Remove old entries from the left
@@ -129,9 +154,7 @@ class ResourceMonitor:
         ):
             self.measurement_history.popleft()
 
-    async def _measure(
-        self, operation_id: UUID, log: bool = True
-    ) -> SingleDataResponse[Measurement[Usage], None]:
+    async def _measure(self, log: bool = False, publish: bool = False):
         """Collect current resource usage and store in history."""
         executed_at = datetime.now(tz=timezone.utc)
 
@@ -147,19 +170,14 @@ class ResourceMonitor:
 
         timestamp = Timestamp.completed_now(executed_at)
 
-        cpu_usage = CPUUsage.new(
-            raw=raw_cpu, smooth=smooth_cpu, config=self.config.usage.cpu
-        )
-        memory_usage = MemoryUsage.new(raw=raw_memory, config=self.config.usage.memory)
-        usage = Usage(cpu=cpu_usage, memory=memory_usage)
-        status = aggregate_status(
-            usage.cpu.status,
-            usage.memory.status,
-        )
-        measurement = Measurement[Usage](
+        measurement = RegularMeasurement.new(
             measured_at=timestamp.completed_at,
-            status=status,
-            usage=usage,
+            usage=Usage(
+                cpu=CPUUsage.new(
+                    raw=raw_cpu, smooth=smooth_cpu, config=self.config.usage.cpu
+                ),
+                memory=MemoryUsage.new(raw=raw_memory, config=self.config.usage.memory),
+            ),
         )
 
         # Store in history with timestamp
@@ -168,50 +186,90 @@ class ResourceMonitor:
         # Clean up old entries (older than max retention period)
         self._cleanup_old_entries()
 
-        response = SingleDataResponse[Measurement[Usage], None](
-            data=measurement, metadata=None, other=None
+        response = SingleDataResponse[RegularMeasurement, None].new(data=measurement)
+
+        operation = SuccessfulSystemOperation[
+            SingleDataResponse[RegularMeasurement, None]
+        ](
+            application_context=self.application_context,
+            id=self.operation_id,
+            context=self.operation_context,
+            action=self.operation_action,
+            timestamp=timestamp,
+            summary=(
+                f"Successfully measured resource usage - {measurement.status}"
+                f" - CPU | Status: {measurement.usage.cpu.status}"
+                f" | Raw: {measurement.usage.cpu.raw:.2f}%"
+                f" | Smooth: {measurement.usage.cpu.smooth:.2f}%"
+                f" - Memory | Status: {measurement.usage.memory.status}"
+                f" | Raw: {measurement.usage.memory.raw:.2f}MB"
+                f" | Percentage: {measurement.usage.memory.percentage:.2f}%"
+            ),
+            connection_context=None,
+            authentication=None,
+            authorization=None,
+            impersonation=None,
+            response=response,
         )
 
         if log:
-            SuccessfulSystemOperation[SingleDataResponse[Measurement[Usage], None]](
-                application_context=self.application_context,
-                id=operation_id,
-                context=self.operation_context,
-                action=self.operation_action,
-                timestamp=timestamp,
-                summary=(
-                    f"Successfully measured resource usage - {status}"
-                    f" - CPU | Status: {cpu_usage.status} | Raw: {cpu_usage.raw:.2f}% | Smooth: {cpu_usage.smooth:.2f}%"
-                    f" - Memory | Status {memory_usage.status} | Raw: {memory_usage.raw:.2f}MB | Percentage: {memory_usage.percentage:.2f}%"
-                ),
-                connection_context=None,
-                authentication=None,
-                authorization=None,
-                impersonation=None,
-                response=response,
-            ).log(self.logger, STATUS_LOG_LEVEL[status])
+            operation.log(self.logger, STATUS_LOG_LEVEL[measurement.status])
+        operation.publish(self.logger, self.operation_publishers)
 
-        return response
+        if self.publish and publish and self.publisher is not None:
+            topic_path = self.publisher.client.topic_path(
+                self.publisher.project_id, self.publisher.topic_id
+            )
+            try:
+                future: Future = self.publisher.client.publish(
+                    topic=topic_path,
+                    data=measurement.message_bytes,
+                    **self.application_context.model_dump(mode="json"),
+                )
+                message_id: str = future.result()
+
+                self.logger.debug(
+                    f"Successfully published resource measurement message {message_id} to {topic_path}",
+                    extra={
+                        "json_fields": {
+                            "measurement": measurement.model_dump(mode="json"),
+                            "message_id": message_id,
+                            "topic_path": topic_path,
+                        }
+                    },
+                )
+
+            except Exception as e:
+                self.logger.error(
+                    f"Failed publishing resource measurement message to {topic_path}",
+                    exc_info=True,
+                    extra={
+                        "json_fields": {
+                            "measurement": measurement.model_dump(mode="json"),
+                            "exc_details": extract_details(e),
+                        }
+                    },
+                )
 
     def get_last_measurement(
         self,
         *,
-        operation_id: OptionalUUID = None,
-        connection_context: OptionalConnectionContext = None,
-        authentication: OptionalAnyAuthentication = None,
-        authorization: OptionalAnyAuthorization = None,
-        impersonation: OptionalImpersonation = None,
-    ) -> Optional[SingleDataResponse[Measurement[Usage], None]]:
+        operation_id: OptUUID = None,
+        connection_context: OptConnectionContext = None,
+        authentication: OptAnyAuthentication = None,
+        authorization: OptAnyAuthorization = None,
+        impersonation: OptImpersonation = None,
+    ) -> SingleDataResponse[RegularMeasurement, None] | None:
         """Get the most recent resource usage data."""
         if not self.measurement_history:
             return None
 
         data = self.measurement_history[-1]
-        response = SingleDataResponse[Measurement[Usage], None](
-            data=data, metadata=None, other=None
-        )
+        response = SingleDataResponse[RegularMeasurement, None].new(data=data)
 
-        SuccessfulSystemOperation[SingleDataResponse[Measurement[Usage], None],](
+        operation = SuccessfulSystemOperation[
+            SingleDataResponse[RegularMeasurement, None]
+        ](
             application_context=self.application_context,
             id=operation_id if operation_id is not None else uuid4(),
             context=self.operation_context,
@@ -223,7 +281,9 @@ class ResourceMonitor:
             authorization=authorization,
             impersonation=impersonation,
             response=response,
-        ).log(self.logger, Level.INFO)
+        )
+        operation.log(self.logger, Level.INFO)
+        operation.publish(self.logger, self.operation_publishers)
 
         return response
 
@@ -239,12 +299,12 @@ class ResourceMonitor:
         self,
         window: int = 60,
         *,
-        operation_id: OptionalUUID = None,
-        connection_context: OptionalConnectionContext = None,
-        authentication: OptionalAnyAuthentication = None,
-        authorization: OptionalAnyAuthorization = None,
-        impersonation: OptionalImpersonation = None,
-    ) -> MultipleDataResponse[Measurement[Usage], FlexiblePagination, None]:
+        operation_id: OptUUID = None,
+        connection_context: OptConnectionContext = None,
+        authentication: OptAnyAuthentication = None,
+        authorization: OptAnyAuthorization = None,
+        impersonation: OptImpersonation = None,
+    ) -> MultipleDataResponse[RegularMeasurement, FlexiblePagination, None]:
         """
         Get resource usage data from the last X seconds.
 
@@ -252,7 +312,7 @@ class ResourceMonitor:
             window: Number of seconds to look back
 
         Returns:
-            List of dicts with 'timestamp' and 'resource_usage' keys
+            List of RegularMeasurement
         """
         operation_id = operation_id if operation_id is not None else uuid4()
         executed_at = datetime.now(tz=timezone.utc)
@@ -277,12 +337,12 @@ class ResourceMonitor:
             total_pages=1,
         )
 
-        response = MultipleDataResponse[Measurement[Usage], FlexiblePagination, None](
-            data=data, pagination=pagination, metadata=None, other=None
-        )
+        response = MultipleDataResponse[
+            RegularMeasurement, FlexiblePagination, None
+        ].new(data=data, pagination=pagination)
 
-        SuccessfulSystemOperation[
-            MultipleDataResponse[Measurement[Usage], FlexiblePagination, None],
+        operation = SuccessfulSystemOperation[
+            MultipleDataResponse[RegularMeasurement, FlexiblePagination, None],
         ](
             application_context=self.application_context,
             id=operation_id,
@@ -295,9 +355,9 @@ class ResourceMonitor:
             authorization=authorization,
             impersonation=impersonation,
             response=response,
-        ).log(
-            self.logger, Level.INFO
         )
+        operation.log(self.logger, Level.INFO)
+        operation.publish(self.logger, self.operation_publishers)
 
         return response
 
@@ -305,12 +365,12 @@ class ResourceMonitor:
         self,
         window: int = 60,
         *,
-        operation_id: OptionalUUID = None,
-        connection_context: OptionalConnectionContext = None,
-        authentication: OptionalAnyAuthentication = None,
-        authorization: OptionalAnyAuthorization = None,
-        impersonation: OptionalImpersonation = None,
-    ) -> Optional[SingleDataResponse[Measurement[AggregateUsage], None]]:
+        operation_id: OptUUID = None,
+        connection_context: OptConnectionContext = None,
+        authentication: OptAnyAuthentication = None,
+        authorization: OptAnyAuthorization = None,
+        impersonation: OptImpersonation = None,
+    ) -> SingleDataResponse[AverageMeasurement, None] | None:
         """
         Calculate average resource usage over the last X seconds.
 
@@ -343,35 +403,27 @@ class ResourceMonitor:
         total_memory = sum(entry.usage.memory.raw for entry in history_data)
         count = len(history_data)
 
-        avg_cpu = CPUUsage.new(
-            raw=total_raw_cpu / count,
-            smooth=total_smooth_cpu / count,
-            config=self.config.usage.cpu,
-        )
-
-        avg_memory = MemoryUsage.new(
-            raw=total_memory / count, config=self.config.usage.memory
-        )
-
-        status = aggregate_status(
-            avg_cpu.status,
-            avg_memory.status,
-        )
-
         timestamp = Timestamp.completed_now(executed_at)
 
-        data = Measurement[AggregateUsage](
+        measurement = AverageMeasurement.new(
             measured_at=measured_at,
-            status=status,
-            usage=AggregateUsage(cpu=avg_cpu, memory=avg_memory, window=window),
+            window=window,
+            usage=Usage(
+                cpu=CPUUsage.new(
+                    raw=total_raw_cpu / count,
+                    smooth=total_smooth_cpu / count,
+                    config=self.config.usage.cpu,
+                ),
+                memory=MemoryUsage.new(
+                    raw=total_memory / count, config=self.config.usage.memory
+                ),
+            ),
         )
 
-        response = SingleDataResponse[Measurement[AggregateUsage], None](
-            data=data, metadata=None, other=None
-        )
+        response = SingleDataResponse[AverageMeasurement, None].new(data=measurement)
 
-        SuccessfulSystemOperation[
-            SingleDataResponse[Measurement[AggregateUsage], None],
+        operation = SuccessfulSystemOperation[
+            SingleDataResponse[AverageMeasurement, None]
         ](
             application_context=self.application_context,
             id=operation_id,
@@ -379,18 +431,22 @@ class ResourceMonitor:
             action=self.operation_action,
             timestamp=timestamp,
             summary=(
-                f"Successfully measured average resource usage of the last {window} seconds - {status}"
-                f" - CPU | Status: {avg_cpu.status} | Raw: {avg_cpu.raw:.2f}% | Smooth: {avg_cpu.smooth:.2f}%"
-                f" - Memory | Status: {avg_memory.status} | Raw: {avg_memory.raw:.2f}MB | Percentage: {avg_memory.percentage:.2f}%"
+                f"Successfully measured average resource usage of the last {window} seconds - {measurement.status}"
+                f" - CPU | Status: {measurement.usage.cpu.status}"
+                f" | Raw: {measurement.usage.cpu.raw:.2f}%"
+                f" | Smooth: {measurement.usage.cpu.smooth:.2f}%"
+                f" - Memory | Status: {measurement.usage.memory.status}"
+                f" | Raw: {measurement.usage.memory.raw:.2f}MB"
+                f" | Percentage: {measurement.usage.memory.percentage:.2f}%"
             ),
             connection_context=connection_context,
             authentication=authentication,
             authorization=authorization,
             impersonation=impersonation,
             response=response,
-        ).log(
-            self.logger, Level.INFO
         )
+        operation.log(self.logger, Level.INFO)
+        operation.publish(self.logger, self.operation_publishers)
 
         return response
 
@@ -398,12 +454,12 @@ class ResourceMonitor:
         self,
         window: int = 60,
         *,
-        operation_id: OptionalUUID = None,
-        connection_context: OptionalConnectionContext = None,
-        authentication: OptionalAnyAuthentication = None,
-        authorization: OptionalAnyAuthorization = None,
-        impersonation: OptionalImpersonation = None,
-    ) -> Optional[SingleDataResponse[Measurement[AggregateUsage], None]]:
+        operation_id: OptUUID = None,
+        connection_context: OptConnectionContext = None,
+        authentication: OptAnyAuthentication = None,
+        authorization: OptAnyAuthorization = None,
+        impersonation: OptImpersonation = None,
+    ) -> SingleDataResponse[PeakMeasurement, None] | None:
         """
         Get peak resource usage over the last X seconds.
 
@@ -435,33 +491,27 @@ class ResourceMonitor:
         peak_smooth_cpu = max(entry.usage.cpu.smooth for entry in history_data)
         peak_raw_memory = max(entry.usage.memory.raw for entry in history_data)
 
-        peak_cpu = CPUUsage.new(
-            raw=peak_raw_cpu, smooth=peak_smooth_cpu, config=self.config.usage.cpu
-        )
-
-        peak_memory = MemoryUsage.new(
-            raw=peak_raw_memory, config=self.config.usage.memory
-        )
-
-        status = aggregate_status(
-            peak_cpu.status,
-            peak_memory.status,
-        )
-
         timestamp = Timestamp.completed_now(executed_at)
 
-        data = Measurement[AggregateUsage](
+        measurement = PeakMeasurement.new(
             measured_at=measured_at,
-            status=status,
-            usage=AggregateUsage(cpu=peak_cpu, memory=peak_memory, window=window),
+            window=window,
+            usage=Usage(
+                cpu=CPUUsage.new(
+                    raw=peak_raw_cpu,
+                    smooth=peak_smooth_cpu,
+                    config=self.config.usage.cpu,
+                ),
+                memory=MemoryUsage.new(
+                    raw=peak_raw_memory, config=self.config.usage.memory
+                ),
+            ),
         )
 
-        response = SingleDataResponse[Measurement[AggregateUsage], None](
-            data=data, metadata=None, other=None
-        )
+        response = SingleDataResponse[PeakMeasurement, None].new(data=measurement)
 
-        SuccessfulSystemOperation[
-            SingleDataResponse[Measurement[AggregateUsage], None],
+        operation = SuccessfulSystemOperation[
+            SingleDataResponse[PeakMeasurement, None]
         ](
             application_context=self.application_context,
             id=operation_id,
@@ -469,30 +519,34 @@ class ResourceMonitor:
             action=self.operation_action,
             timestamp=timestamp,
             summary=(
-                f"Successfully measured peak resource usage of the last {window} seconds - {status}"
-                f" - CPU | Status: {peak_cpu.status} | Raw: {peak_cpu.raw:.2f}% | Smooth: {peak_cpu.smooth:.2f}%"
-                f" - Memory | Status: {peak_memory.status} | Raw: {peak_memory.raw:.2f}MB | Percentage: {peak_memory.percentage:.2f}%"
+                f"Successfully measured peak resource usage of the last {window} seconds - {measurement.status}"
+                f" - CPU | Status: {measurement.usage.cpu.status}"
+                f" | Raw: {measurement.usage.cpu.raw:.2f}%"
+                f" | Smooth: {measurement.usage.cpu.smooth:.2f}%"
+                f" - Memory | Status: {measurement.usage.memory.status}"
+                f" | Raw: {measurement.usage.memory.raw:.2f}MB"
+                f" | Percentage: {measurement.usage.memory.percentage:.2f}%"
             ),
             connection_context=connection_context,
             authentication=authentication,
             authorization=authorization,
             impersonation=impersonation,
             response=response,
-        ).log(
-            self.logger, Level.INFO
         )
+        operation.log(self.logger, Level.INFO)
+        operation.publish(self.logger, self.operation_publishers)
 
         return response
 
     async def get_instant_usage(
         self,
         *,
-        operation_id: OptionalUUID = None,
-        connection_context: OptionalConnectionContext = None,
-        authentication: OptionalAnyAuthentication = None,
-        authorization: OptionalAnyAuthorization = None,
-        impersonation: OptionalImpersonation = None,
-    ) -> SingleDataResponse[Measurement[Usage], None]:
+        operation_id: OptUUID = None,
+        connection_context: OptConnectionContext = None,
+        authentication: OptAnyAuthentication = None,
+        authorization: OptAnyAuthorization = None,
+        impersonation: OptImpersonation = None,
+    ) -> SingleDataResponse[RegularMeasurement, None]:
         """
         Get an instant resource usage reading without affecting the monitoring loop.
         This doesn't store the result in history.
@@ -509,44 +563,45 @@ class ResourceMonitor:
             sum(self.cpu_window) / len(self.cpu_window) if self.cpu_window else raw_cpu
         )
 
-        measured_at = datetime.now(tz=timezone.utc)
-
-        cpu_usage = CPUUsage.new(
-            raw=raw_cpu, smooth=smooth_cpu, config=self.config.usage.cpu
-        )
-        memory_usage = MemoryUsage.new(raw=raw_memory, config=self.config.usage.memory)
-
-        usage = Usage(cpu=cpu_usage, memory=memory_usage)
-        status = aggregate_status(
-            usage.cpu.status,
-            usage.memory.status,
-        )
-
         timestamp = Timestamp.completed_now(executed_at)
 
-        data = Measurement(measured_at=measured_at, status=status, usage=usage)
-
-        response = SingleDataResponse[Measurement[Usage], None](
-            data=data, metadata=None, other=None
+        measurement = RegularMeasurement.new(
+            measured_at=timestamp.completed_at,
+            usage=Usage(
+                cpu=CPUUsage.new(
+                    raw=raw_cpu, smooth=smooth_cpu, config=self.config.usage.cpu
+                ),
+                memory=MemoryUsage.new(raw=raw_memory, config=self.config.usage.memory),
+            ),
         )
 
-        SuccessfulSystemOperation[SingleDataResponse[Measurement[Usage], None],](
+        response = SingleDataResponse[RegularMeasurement, None].new(data=measurement)
+
+        operation = SuccessfulSystemOperation[
+            SingleDataResponse[RegularMeasurement, None]
+        ](
             application_context=self.application_context,
             id=operation_id,
             context=self.operation_context,
             action=self.operation_action,
             timestamp=timestamp,
             summary=(
-                f"Successfully measured instant resource usage - {status}"
-                f" - CPU | Status: {cpu_usage.status} | Raw: {cpu_usage.raw:.2f}% | Smooth: {cpu_usage.smooth:.2f}%"
-                f" - Memory | Status: {memory_usage.status} | Raw: {memory_usage.raw:.2f}MB | Percentage: {memory_usage.percentage:.2f}%"
+                f"Successfully measured instant resource usage - {measurement.status}"
+                f" - CPU | Status: {measurement.usage.cpu.status}"
+                f" | Raw: {measurement.usage.cpu.raw:.2f}%"
+                f" | Smooth: {measurement.usage.cpu.smooth:.2f}%"
+                f" - Memory | Status: {measurement.usage.memory.status}"
+                f" | Raw: {measurement.usage.memory.raw:.2f}MB"
+                f" | Percentage: {measurement.usage.memory.percentage:.2f}%"
             ),
             connection_context=connection_context,
             authentication=authentication,
             authorization=authorization,
             impersonation=impersonation,
             response=response,
-        ).log(self.logger, Level.INFO)
+        )
+        operation.log(self.logger, Level.INFO)
+        operation.publish(self.logger, self.operation_publishers)
 
         return response
 
